@@ -49,6 +49,7 @@
 #include "gdcmASN1.h"
 #include "gdcmAttribute.h"
 #include "gdcmBase64.h"
+#include "gdcmMEC_MR3.h"
 #include "gdcmTagKeywords.h"
 
 #include <string>
@@ -493,7 +494,7 @@ struct Data2
    os << "  UserAdress4: " << std::string(UserAdress4,32) << "\n";
    os << "  UserAdress5: " << std::string(UserAdress5,32) << "\n";
    os << "  RecDate: "     << std::string(RecDate,8) << "\n";
-   os << "  RecTime: "     << std::string(RecTime,64) << "\n";
+   os << "  RecTime: "     << std::string(RecTime,6) << "\n";
    os << "  RecPlace: "    << std::string(RecPlace,64) << "\n";
    os << "  RecSource: "   << std::string(RecSource,64) << "\n";
    os << "  DF1: "         << std::string(DF1,64) << "\n";
@@ -853,6 +854,38 @@ static int PrintCT3(const std::string & filename, bool verbose)
   return ret;
 }
 
+static int PrintMEC_MR3(const std::string & filename, bool verbose)
+{
+  (void)verbose;
+  gdcm::Reader reader;
+  reader.SetFileName( filename.c_str() );
+  if( !reader.Read() )
+    {
+    std::cerr << "Failed to read: " << filename << std::endl;
+    return 1;
+    }
+
+  const gdcm::DataSet& ds = reader.GetFile().GetDataSet();
+
+  // Original Data
+  const gdcm::PrivateTag tmecmr3(0x700d,0x08,"TOSHIBA_MEC_MR3");
+  if( !ds.FindDataElement( tmecmr3) ) return 1;
+  const gdcm::DataElement& mecmr3 = ds.GetDataElement( tmecmr3 );
+  if ( mecmr3.IsEmpty() ) return 1;
+  const gdcm::ByteValue * bv = mecmr3.GetByteValue();
+
+  const char *inbuffer = bv->GetPointer();
+  const size_t buf_len= bv->GetLength();
+
+  int ret = 0;
+  if (!gdcm::MEC_MR3::Print(inbuffer, buf_len))
+  {
+    ret = 1;
+  }
+
+  return ret;
+}
+
 static int PrintPMTF(const std::string & filename, bool verbose)
 {
   (void)verbose;
@@ -1211,6 +1244,7 @@ static void PrintHelp()
   std::cout << "                      or TOSHIBA_MEC_MR3 sub-sequences (0029,01,TOSHIBA_MEC_MR3)." << std::endl;
   std::cout << "                      or CANON_MEC_MR3 sub-sequences (0029,01,CANON_MEC_MR3)." << std::endl;
   std::cout << "     --medcom         print MedCom History Information as UTF-8 (0029,20,SIEMENS MEDCOM HEADER)." << std::endl;
+  std::cout << "     --mr3            print Original Data as UTF-8 (700d,08,TOSHIBA_MEC_MR3)." << std::endl;
   std::cout << "  -A --asn1           print encapsulated ASN1 structure >(0400,0520)." << std::endl;
   std::cout << "     --map-uid-names  map UID to names." << std::endl;
   std::cout << "General Options:" << std::endl;
@@ -1244,6 +1278,7 @@ int main (int argc, char *argv[])
   int printvepro = 0;
   int printsds = 0; // MR Series Data Storage
   int printct3 = 0; // TOSHIBA_MEC_CT3
+  int printmecmr3 = 0; // TOSHIBA_MEC_MR3
   int printpmtf = 0; // TOSHIBA / PMTF INFORMATION DATA & TOSHIBA / TOSHIBA_MEC_MR3 & CANON_MEC_MR3
   int verbose = 0;
   int warning = 0;
@@ -1293,6 +1328,7 @@ int main (int argc, char *argv[])
         {"pmtf", 0, &printpmtf, 1},
         {"mecmr3", 0, &printpmtf, 1},
         {"medcom", 0, &printmedcom, 1},
+        {"mr3", 0, &printmecmr3, 1},
         {nullptr, 0, nullptr, 0} // required
     };
     static const char short_options[] = "i:xrpdcCPAVWDEhvI";
@@ -1514,6 +1550,10 @@ int main (int argc, char *argv[])
         {
         res += PrintPMTF(*it, verbose!= 0);
         }
+      else if( printmecmr3 )
+        {
+        res += PrintMEC_MR3(*it, verbose!=0);
+        }
       else if( printmedcom )
         {
         res += PrintMedComHistory(*it, verbose!=0);
@@ -1577,6 +1617,10 @@ int main (int argc, char *argv[])
       {
       res += PrintPMTF(filename, verbose!= 0);
       }
+    else if( printmecmr3 )
+      {
+      res += PrintMEC_MR3(filename, verbose!= 0);
+      }
     else if( printmedcom )
       {
       res += PrintMedComHistory(filename, verbose!= 0);
